@@ -3,6 +3,7 @@
 import daiquiri
 from dbnomics_data_model import DatasetCode, ProviderCode
 
+from dbnomics_solr import services
 from dbnomics_solr.dbnomics_solr_client import DBnomicsSolrClient
 
 __all__ = ["delete_dataset_docs"]
@@ -29,5 +30,7 @@ def delete_dataset_docs(
     logger.info("Deleting all the Solr documents related to that dataset...", dataset_id=dataset_id)
     dbnomics_solr_client.delete_dataset_docs(provider_code, dataset_code)
 
+    services.update_top_level_counts(commit=False, dbnomics_solr_client=dbnomics_solr_client)
+
     dbnomics_solr_client.commit()
     logger.info("All the Solr documents related to that dataset were deleted", dataset_id=dataset_id)
