@@ -21,6 +21,7 @@ def delete_extra_datasets(
     dbnomics_solr_client: DBnomicsSolrClient,
     storage: FileSystemStorage,
     storage_dataset_codes: Optional[Iterable[DatasetCode]] = None,
+    update_top_level_counts: bool = True,
 ):
     """Delete the extra datasets related to that provider."""
     extra_dataset_codes = services.search_extra_datasets(
@@ -33,4 +34,8 @@ def delete_extra_datasets(
         dataset_id = f"{provider_code}/{dataset_code}"
         logger.info("Deleting the extra dataset", dataset_id=dataset_id)
         dbnomics_solr_client.delete_dataset_docs(provider_code, dataset_code)
+
+    if update_top_level_counts:
+        services.update_top_level_counts(commit=False, dbnomics_solr_client=dbnomics_solr_client)
+
     dbnomics_solr_client.commit()
