@@ -142,6 +142,7 @@ def index_provider(
             dbnomics_solr_client=dbnomics_solr_client,
             storage=storage,
             storage_dataset_codes=storage_dataset_codes,
+            update_top_level_counts=False,
         )
 
     if skipped_dataset_codes:
@@ -151,3 +152,5 @@ def index_provider(
             sorted(skipped_dataset_codes),
             provider_code=provider_code,
         )
+
+    services.update_top_level_counts(dbnomics_solr_client=dbnomics_solr_client)
